@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Update Class file."""
 
-import dateparser
+import dateutil.parser
 import logging
 from requests import HTTPError
 
@@ -426,7 +426,7 @@ class Update(object):
         # get last modified date from current record
         last_modified = None
         if user:
-            updated_at = dateparser.parse(user['updated_at'])
+            updated_at = dateutil.parser.parse(user['updated_at'])
             last_modified = updated_at.strftime('%a, %d %b %Y %H:%M:%S GMT')
 
         # authenticate with user's token
